@@ -279,6 +279,21 @@ public interface ConfigurationKeys {
      */
     String STORE_DB_PREFIX = "store.db.";
 
+    /**
+     * The constant STORE_DB_DRUID_PREFIX.
+     */
+    String STORE_DB_DRUID_PREFIX = "store.db.druid.";
+
+    /**
+     * The constant STORE_DB_HIKARI_PREFIX.
+     */
+    String STORE_DB_HIKARI_PREFIX = "store.db.hikari.";
+
+    /**
+     * The constant STORE_DB_DBCP_PREFIX.
+     */
+    String STORE_DB_DBCP_PREFIX = "store.db.dbcp.";
+
     /**
      * The constant STORE_REDIS_PREFIX.
      */
@@ -349,11 +364,77 @@ public interface ConfigurationKeys {
      */
     String STORE_DB_LOG_QUERY_LIMIT = STORE_DB_PREFIX + "queryLimit";
 
+    /**
+     * The constant STORE_DB_DRUID_TIME_BETWEEN_EVICTION_RUNS_MILLIS.
+     */
+    String STORE_DB_DRUID_TIME_BETWEEN_EVICTION_RUNS_MILLIS = STORE_DB_DRUID_PREFIX + "timeBetweenEvictionRunsMillis";
+
+    /**
+     * The constant STORE_DB_DRUID_MIN_EVICTABLE_TIME_MILLIS.
+     */
+    String STORE_DB_DRUID_MIN_EVICTABLE_TIME_MILLIS = STORE_DB_DRUID_PREFIX + "minEvictableIdleTimeMillis";
+
+    /**
+     * The constant STORE_DB_DRUID_TEST_WHILE_IDLE.
+     */
+    String STORE_DB_DRUID_TEST_WHILE_IDLE = STORE_DB_DRUID_PREFIX + "testWhileIdle";
+
+    /**
+     * The constant STORE_DB_DRUID_TEST_ON_BORROW.
+     */
+    String STORE_DB_DRUID_TEST_ON_BORROW = STORE_DB_DRUID_PREFIX + "testOnBorrow";
+
+    /**
+     * The constant STORE_DB_DRUID_KEEP_ALIVE.
+     */
+    String STORE_DB_DRUID_KEEP_ALIVE = STORE_DB_DRUID_PREFIX + "keepAlive";
+
+    /**
+     * The constant STORE_DB_HIKARI_IDLE_TIMEOUT.
+     */
+    String STORE_DB_HIKARI_IDLE_TIMEOUT = STORE_DB_HIKARI_PREFIX + "idleTimeout";
+
+    /**
+     * The constant STORE_DB_HIKARI_KEEPALIVE_TIME.
+     */
+    String STORE_DB_HIKARI_KEEPALIVE_TIME = STORE_DB_HIKARI_PREFIX + "keepaliveTime";
+
+    /**
+     * The constant STORE_DB_HIKARI_MAX_LIFE_TIME.
+     */
+    String STORE_DB_HIKARI_MAX_LIFE_TIME = STORE_DB_HIKARI_PREFIX + "maxLifetime";
+
+    /**
+     * The constant STORE_DB_HIKARI_VALIDATION_TIMEOUT.
+     */
+    String STORE_DB_HIKARI_VALIDATION_TIMEOUT = STORE_DB_HIKARI_PREFIX + "validationTimeout";
+
+    /**
+     * The constant STORE_DB_DBCP_TIME_BETWEEN_EVICTION_RUNS_MILLIS.
+     */
+    String STORE_DB_DBCP_TIME_BETWEEN_EVICTION_RUNS_MILLIS = STORE_DB_DBCP_PREFIX + "timeBetweenEvictionRunsMillis";
+
+    /**
+     * The constant STORE_DB_DBCP_MIN_EVICTABLE_TIME_MILLIS.
+     */
+    String STORE_DB_DBCP_MIN_EVICTABLE_TIME_MILLIS = STORE_DB_DBCP_PREFIX + "minEvictableIdleTimeMillis";
+
+    /**
+     * The constant STORE_DB_DBCP_TEST_WHILE_IDLE.
+     */
+    String STORE_DB_DBCP_TEST_WHILE_IDLE = STORE_DB_DBCP_PREFIX + "testWhileIdle";
+
+    /**
+     * The constant STORE_DB_DBCP_TEST_ON_BORROW.
+     */
+    String STORE_DB_DBCP_TEST_ON_BORROW = STORE_DB_DBCP_PREFIX + "testOnBorrow";
+
     /**
      * The constant LOCK_DB_TABLE.
      */
     String LOCK_DB_TABLE = STORE_DB_PREFIX + "lockTable";
 
+
     /**
      * The constant SERVER_RPC_PORT.
      */
@@ -394,6 +475,11 @@ public interface ConfigurationKeys {
      */
     String ROLLBACKING_RETRY_PERIOD = RECOVERY_PREFIX + "rollbackingRetryPeriod";
 
+    /**
+     * The constant END_STATUS_RETRY_PERIOD.
+     */
+    String END_STATUS_RETRY_PERIOD = RECOVERY_PREFIX + "endstatusRetryPeriod";
+
     /**
      * The constant TIMEOUT_RETRY_PERIOD.
      */
@@ -518,6 +604,11 @@ public interface ConfigurationKeys {
      */
     String RETRY_DEAD_THRESHOLD = SERVER_PREFIX + "retryDeadThreshold";
 
+    /**
+     * the constant END_STATE_RETRY_DEAD_THRESHOLD
+     */
+    String END_STATE_RETRY_DEAD_THRESHOLD = SERVER_PREFIX + "endStateRetryDeadThreshold";
+
     /**
      * the constant DISTRIBUTED_LOCK_EXPIRE_TIME
      */
@@ -618,6 +709,11 @@ public interface ConfigurationKeys {
      */
     String WORKER_THREAD_SIZE = THREAD_FACTORY_PREFIX + "workerThreadSize";
 
+    /**
+     * The constant ENABLE_SHARED_EVENTLOOP
+     */
+    String ENABLE_CLIENT_SHARED_EVENTLOOP = TRANSPORT_PREFIX + "enableClientSharedEventLoopGroup";
+
     /**
      * The constant SHUTDOWN_PREFIX
      */
@@ -1020,11 +1116,6 @@ public interface ConfigurationKeys {
      */
     String SERVER_RAFT_COMPRESSOR = SERVER_RAFT + "compressor";
 
-    /**
-     * The constant CLIENT_METADATA_MAX_AGE_MS.
-     */
-    String CLIENT_METADATA_MAX_AGE_MS = CLIENT_PREFIX + "metadataMaxAgeMs";
-
     /**
      * The constant IS_USE_CLOUD_NAMESPACE_PARSING.
      */
@@ -1131,4 +1222,30 @@ public interface ConfigurationKeys {
      */
     String SERVER_REGISTRY_METADATA_EXTERNAL = SERVER_REGISTRY_METADATA_PREFIX + ".external";
 
+
+    /**
+     * The constant RATE_LIMIT_PREFIX.
+     */
+    String RATE_LIMIT_PREFIX = SERVER_PREFIX + "ratelimit";
+
+    /**
+     * The constant RATE_LIMIT_BUCKET_TOKEN_NUM_PER_SECOND.
+     */
+    String RATE_LIMIT_BUCKET_TOKEN_NUM_PER_SECOND = RATE_LIMIT_PREFIX + ".bucketTokenNumPerSecond";
+
+    /**
+     * The constant RATE_LIMIT_ENABLE.
+     */
+    String RATE_LIMIT_ENABLE = RATE_LIMIT_PREFIX + ".enable";
+
+    /**
+     * The constant RATE_LIMIT_BUCKET_TOKEN_MAX_NUM.
+     */
+    String RATE_LIMIT_BUCKET_TOKEN_MAX_NUM = RATE_LIMIT_PREFIX + ".bucketTokenMaxNum";
+
+    /**
+     * The constant RATE_LIMIT_BUCKET_TOKEN_INITIAL_NUM.
+     */
+    String RATE_LIMIT_BUCKET_TOKEN_INITIAL_NUM = RATE_LIMIT_PREFIX + ".bucketTokenInitialNum";
+
 }
