@@ -24,6 +24,8 @@ import com.github.luben.zstd.Zstd;
  */
 public class ZstdUtil {
 
+    public static final int MAX_COMPRESSED_SIZE = 4 * 1024 * 1024;
+
     public static byte[] compress(byte[] bytes) {
         if (bytes == null) {
             throw new NullPointerException("bytes is null");
@@ -37,8 +39,12 @@ public class ZstdUtil {
             throw new NullPointerException("bytes is null");
         }
 
-        int size = (int) Zstd.decompressedSize(bytes);
-        byte[] decompressBytes = new byte[size];
+        long size = Zstd.decompressedSize(bytes);
+        if (size < 0 || size > MAX_COMPRESSED_SIZE) {
+            throw new IllegalArgumentException(
+                "Invalid decompressed size: " + size + ", the value of size ranges from 0 to " + MAX_COMPRESSED_SIZE);
+        }
+        byte[] decompressBytes = new byte[(int)size];
         Zstd.decompress(decompressBytes, bytes);
         return decompressBytes;
     }
