@@ -19,7 +19,7 @@ package org.apache.seata.namingserver;
 import org.springframework.boot.SpringApplication;
 import org.springframework.boot.autoconfigure.SpringBootApplication;
 
-@SpringBootApplication
+@SpringBootApplication(scanBasePackages = {"org.apache.seata"})
 public class NamingserverApplication {
 
     public static void main(String[] args) {
