@@ -16,6 +16,8 @@
  */
 package org.apache.seata.server.cluster.raft.execute;
 
+import org.apache.seata.server.session.SessionHolder;
+import org.apache.seata.server.store.VGroupMappingStoreManager;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -30,4 +32,6 @@ public abstract class AbstractRaftMsgExecute implements RaftMsgExecute<Boolean>
 
     protected RaftLockManager raftLockManager = (RaftLockManager)LockerManagerFactory.getLockManager();
 
+    protected VGroupMappingStoreManager raftVGroupMappingStoreManager = SessionHolder.getRootVGroupMappingManager();
+
 }
