@@ -35,8 +35,9 @@ import org.apache.seata.config.ConfigurationFactory;
 import org.apache.seata.common.result.PageResult;
 import org.apache.seata.core.store.db.DataSourceProvider;
 import org.apache.seata.core.store.db.sql.log.LogStoreSqlsFactory;
+import org.apache.seata.server.console.impl.AbstractBranchService;
 import org.apache.seata.server.console.service.BranchSessionService;
-import org.apache.seata.server.console.vo.BranchSessionVO;
+import org.apache.seata.server.console.entity.vo.BranchSessionVO;
 import org.springframework.boot.autoconfigure.condition.ConditionalOnExpression;
 import org.springframework.stereotype.Component;
 
@@ -49,7 +50,7 @@ import static org.apache.seata.common.DefaultValues.DEFAULT_STORE_DB_BRANCH_TABL
 @Component
 @org.springframework.context.annotation.Configuration
 @ConditionalOnExpression("#{'db'.equals('${sessionMode}')}")
-public class BranchSessionDBServiceImpl implements BranchSessionService {
+public class BranchSessionDBServiceImpl extends AbstractBranchService implements BranchSessionService {
 
     private String branchTable;
 
