@@ -16,13 +16,22 @@
  */
 package org.apache.seata.server.console.impl.file;
 
-import org.apache.seata.common.exception.NotSupportYetException;
-import org.apache.seata.server.console.vo.BranchSessionVO;
+import org.apache.seata.common.util.StringUtils;
+import org.apache.seata.server.console.impl.AbstractBranchService;
+import org.apache.seata.server.console.entity.vo.BranchSessionVO;
 import org.apache.seata.common.result.PageResult;
 import org.apache.seata.server.console.service.BranchSessionService;
+import org.apache.seata.server.session.GlobalSession;
+import org.apache.seata.server.session.SessionHolder;
+import org.apache.seata.server.storage.SessionConverter;
 import org.springframework.boot.autoconfigure.condition.ConditionalOnExpression;
 import org.springframework.stereotype.Component;
 
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.List;
+import java.util.Set;
+
 /**
  * Branch Session File ServiceImpl
  *
@@ -30,10 +39,22 @@ import org.springframework.stereotype.Component;
 @Component
 @org.springframework.context.annotation.Configuration
 @ConditionalOnExpression("#{'file'.equals('${sessionMode}')}")
-public class BranchSessionFileServiceImpl implements BranchSessionService {
+public class BranchSessionFileServiceImpl extends AbstractBranchService implements BranchSessionService {
 
     @Override
     public PageResult<BranchSessionVO> queryByXid(String xid) {
-        throw new NotSupportYetException();
+        if (StringUtils.isBlank(xid)) {
+            throw new IllegalArgumentException("xid should not be blank");
+        }
+        List<BranchSessionVO> branchSessionVOList = new ArrayList<>(0);
+        final Collection<GlobalSession> allSessions = SessionHolder.getRootSessionManager().allSessions();
+        for (GlobalSession globalSession : allSessions) {
+            if (globalSession.getXid().equals(xid)) {
+                Set<BranchSessionVO> branchSessionVOS = SessionConverter.convertBranchSession(globalSession.getBranchSessions());
+                branchSessionVOList = new ArrayList<>(branchSessionVOS);
+                break;
+            }
+        }
+        return PageResult.success(branchSessionVOList, branchSessionVOList.size(), 0, 0, 0);
     }
 }
