@@ -16,14 +16,10 @@
  */
 package org.apache.seata.server.metrics;
 
-import java.util.HashMap;
-import java.util.Map;
-import java.util.concurrent.TimeUnit;
-import java.util.function.Consumer;
-
 import com.google.common.eventbus.Subscribe;
 import org.apache.seata.core.event.ExceptionEvent;
 import org.apache.seata.core.event.GlobalTransactionEvent;
+import org.apache.seata.core.event.RateLimitEvent;
 import org.apache.seata.core.model.GlobalStatus;
 import org.apache.seata.metrics.Id;
 import org.apache.seata.metrics.registry.Registry;
@@ -31,8 +27,16 @@ import org.apache.seata.server.event.EventBusManager;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
+import java.util.HashMap;
+import java.util.Map;
+import java.util.concurrent.TimeUnit;
+import java.util.function.Consumer;
+
 import static org.apache.seata.metrics.IdConstants.APP_ID_KEY;
+import static org.apache.seata.metrics.IdConstants.CLIENT_ID_KEY;
 import static org.apache.seata.metrics.IdConstants.GROUP_KEY;
+import static org.apache.seata.metrics.IdConstants.LIMIT_TYPE_KEY;
+import static org.apache.seata.metrics.IdConstants.HOST_AND_PORT;
 import static org.apache.seata.metrics.IdConstants.STATUS_VALUE_AFTER_COMMITTED_KEY;
 import static org.apache.seata.metrics.IdConstants.STATUS_VALUE_AFTER_ROLLBACKED_KEY;
 
@@ -193,6 +197,15 @@ public class MetricsSubscriber {
                 .withTag(APP_ID_KEY, event.getName())).increase(1);
     }
 
+    @Subscribe
+    public void recordRateLimitEventForMetrics(RateLimitEvent event) {
+        registry.getSummary(MeterIdConstants.SUMMARY_RATE_LIMIT
+                .withTag(LIMIT_TYPE_KEY, event.getLimitType())
+                .withTag(APP_ID_KEY, event.getApplicationId())
+                .withTag(CLIENT_ID_KEY, event.getClientId())
+                .withTag(HOST_AND_PORT, event.getServerIpAddressAndPort())).increase(1);
+    }
+
     @Override
     public boolean equals(Object obj) {
         return this.getClass().getName().equals(obj.getClass().getName());
