@@ -24,8 +24,8 @@ import java.util.Collections;
 import org.apache.seata.common.util.CollectionUtils;
 import org.apache.seata.common.util.StringUtils;
 import org.apache.seata.server.cluster.raft.sync.msg.dto.BranchTransactionDTO;
-import org.apache.seata.server.console.vo.BranchSessionVO;
-import org.apache.seata.server.console.vo.GlobalSessionVO;
+import org.apache.seata.server.console.entity.vo.BranchSessionVO;
+import org.apache.seata.server.console.entity.vo.GlobalSessionVO;
 import org.apache.seata.core.model.BranchStatus;
 import org.apache.seata.core.model.BranchType;
 import org.apache.seata.core.model.GlobalStatus;
