@@ -127,7 +127,7 @@ class TccActionInterceptorParserTest {
 
 
     @Test
-    void parserInterfaceToProxy() {
+    void parserInterfaceToProxy() throws Exception {
         //given
         TccActionInterceptorParser tccActionInterceptorParser = new TccActionInterceptorParser();
         NormalTccActionImpl tccAction = new NormalTccActionImpl();
